%{?!_licensedir:%global license %%doc}
%{!?upstream_version: %global upstream_version %{version}}

%global sname ironic-python-agent

Name:       openstack-ironic-python-agent
Summary:    A python agent for provisioning and deprovisioning bare metal servers
Version:    2.0.1
Release:    3%{?dist}
License:    ASL 2.0
URL:        https://github.com/openstack/ironic-python-agent

Source0:    https://tarballs.openstack.org/%{sname}/%{sname}-%{upstream_version}.tar.gz
Source1:    openstack-ironic-python-agent.service

# patches_ignore=DROP-IN-RPM
# patches_base=2.0.1
Patch0001: 0001-Move-legacy-jobs-into-tree.patch
Patch0002: 0002-Zuul-add-file-extension-to-playbook-path.patch
Patch0003: 0003-Revert-Adjust-whitespace-in-setup.cfg.patch
Patch0004: 0004-NUMA-topology-collector.patch
Patch0005: 0005-Fix-compatibility-with-Pint-0.5.patch
Patch0006: 0006-Report-dev-disk-by-path-on-inspection.patch
Patch0007: 0007-Clean-up-zuul.d-files.patch
Patch0008: 0008-Use-the-tempest-plugin-from-openstack-ironic-tempest.patch
Patch0009: 0009-Zuul-Remove-project-name.patch

BuildArch:  noarch
BuildRequires:  python-setuptools
BuildRequires:  python-pbr
BuildRequires:  python2-devel
BuildRequires:  systemd
# These packages are required for running unit tests
BuildRequires: python-eventlet
BuildRequires: python-ironic-lib
BuildRequires: python-iso8601
BuildRequires: python-mock
BuildRequires: python-netifaces
BuildRequires: python-oslo-config
BuildRequires: python-oslo-concurrency
BuildRequires: python-oslo-log
BuildRequires: python-oslo-serialization
BuildRequires: python-oslo-service
BuildRequires: python-oslo-utils
BuildRequires: python-oslotest
BuildRequires: python-os-testr
BuildRequires: python-pecan
BuildRequires: python-pint
BuildRequires: python-psutil
BuildRequires: python-pyudev
BuildRequires: python-requests
BuildRequires: python-rtslib
BuildRequires: python-six
BuildRequires: python-stevedore
BuildRequires: python-wsme

Requires: python-ironic-python-agent = %{upstream_version}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

# TODO(trown) when the following packages are available, package for py3:
# python3-eventlet
# python3-oslo-concurrency
# python3-oslo-log
# python3-oslo-serialization
# python3-oslo-service
# python3-oslo-utils
# python3-pecan
# python3-pint
# python3-wsme

%description
An agent for controlling and deploying Ironic controlled bare metal nodes.

The ironic-python-agent works with the agent driver in Ironic to provision the
node. Starting with ironic-python-agent running on a ramdisk on the
unprovisioned node, Ironic makes API calls to ironic-python-agent to provision
the machine. This allows for greater control and flexibility of the entire
deployment process.

The ironic-python-agent may also be used with the original Ironic pxe drivers
as of the Kilo OpenStack release.

%package -n python-ironic-python-agent
Summary:    Python library for the ironic python agent.
%{?python_provide:%python_provide python-ironic-python-agent}
# python_provide does not exist in CBS Cloud buildroot
Provides:   python-ironic-python-agent = %{upstream_version}

Requires: python-pbr
Requires: python-eventlet
Requires: python-ironic-lib
Requires: python-iso8601
Requires: python-netifaces
Requires: python-netaddr >= 0.7.13
Requires: python-oslo-config >= 2:3.14.0
Requires: python-oslo-concurrency >= 3.8.0
Requires: python-oslo-log >= 3.11.0
Requires: python-oslo-serialization >= 1.10.0
Requires: python-oslo-service >= 1.10.0
Requires: python-oslo-utils >= 3.18.0
Requires: python-pecan
Requires: python-pint
Requires: python-psutil
Requires: python-pyudev
Requires: python-requests
Requires: python-rtslib
Requires: python-six
Requires: python-stevedore >= 1.17.1
Requires: python-wsme

%description -n python-ironic-python-agent
Python library for ironic python agent.

%package -n python-ironic-python-agent-doc
Summary:    Documentation for ironic python agent.
%{?python_provide:%python_provide python-ironic-python-agent-doc}
# python_provide does not exist in CBS Cloud buildroot
Provides:   python-ironic-python-agent-doc = %{upstream_version}

%description -n python-ironic-python-agent-doc
Documentation for ironic python agent.

%prep
%autosetup -v -p 1 -n ironic-python-agent-%{upstream_version}

# Remove the requirements file so that pbr hooks don't add it
# to distutils requires_dist config
rm -rf {test-,}requirements.txt tools/{pip,test}-requires

%build
%{__python2} setup.py build

%install
%{__python2} setup.py install -O1 --skip-build --root=%{buildroot}

# TODO(trown) build the docs as below once we either remove the upstream
# requirement on python-sphinxcontrib-pecanwsme, or it exists in rawhide.
# For now, we will just include the raw restructured text.
# export PYTHONPATH="$( pwd ):$PYTHONPATH"
# pushd doc
# sphinx-build -b html -d build/doctrees  source build/html
# popd

# install systemd scripts
mkdir -p %{buildroot}%{_unitdir}
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}

install -p -D -m 644 etc/ironic_python_agent/ironic_python_agent.conf.sample %{buildroot}/%{_sysconfdir}/ironic-python-agent/agent.conf

%check
ostestr --path ironic_python_agent/tests/unit

%files
%doc README.rst
%license LICENSE
%config(noreplace) %attr(-,root,root) %{_sysconfdir}/ironic-python-agent
%{_bindir}/ironic-python-agent
%{_unitdir}/openstack-ironic-python-agent.service

%files -n python-ironic-python-agent
%license LICENSE
%{python2_sitelib}/ironic_python_agent
%{python2_sitelib}/ironic_python_agent*.egg-info

%files -n python-ironic-python-agent-doc
%doc doc/source
%license LICENSE

%post
%systemd_post openstack-ironic-python-agent.service

%preun
%systemd_preun openstack-ironic-python-agent.service

%postun
%systemd_postun_with_restart openstack-ironic-python-agent.service

%changelog
* Thu Mar 22 2018 Steve Linabery <slinaber@redhat.com> 2.0.1-3
- Zuul: Remove project name
- Use the tempest plugin from openstack/ironic-tempest-plugin
- Clean-up zuul.d/ files
- Report /dev/disk/by-path on inspection (rhbz#1522864)

* Fri Jan 05 2018 Steve Linabery <slinaber@redhat.com> 2.0.1-2
- Fix compatibility with Pint 0.5
- NUMA-topology collector
- Revert "Adjust whitespace in setup.cfg"
- Zuul: add file extension to playbook path
- Move legacy jobs into tree

* Fri Nov 10 2017 Steve Linabery <slinaber@redhat.com> 2.0.1-1
- Update to 2.0.1

* Fri Jun 23 2017 Steve Linabery <slinaber@redhat.com> 2.0.0-2
- [imagebuild] support requirements referring to /opt/stack/new
- Add option for building IPMItool into TinyIPA
- Updated from global requirements
- Updated from global requirements
- Update UPPER_CONSTRAINTS_FILE for stable/ocata

* Tue Feb 14 2017 Alfredo Moralejo <amoralej@redhat.com> 2.0.0-1
- Update to 2.0.0

